@@ -1,6 +1,6 @@
-//use ruma_identifiers::{Box<RoomId>, Box<UserId>};
+//use ruma_identifiers::{OwnedRoomId, OwnedUserId};
 //use serde::{Serialize, Deserialize};
-use crackle_lib::{RoomAliasId, RoomId, RoomName, ServerName, UserId};
+use crackle_lib::{OwnedRoomAliasId, OwnedRoomId, OwnedRoomName, ServerName, UserId};
 use crossbeam_channel::{unbounded, TryRecvError};
 use crossterm::{
     event::{self, DisableMouseCapture, EnableMouseCapture, Event, KeyCode},
@@ -77,21 +77,21 @@ struct App {
     /// Current input mode
     focus: Focus,
     /// History of recorded messages
-    messages: BTreeMap<Box<RoomId>, Vec<String>>,
+    messages: BTreeMap<OwnedRoomId, Vec<String>>,
     host: String,
     server_name: String,
     user_name: String,
     password: Option<String>,
-    selected_room: Option<Box<RoomId>>,
+    selected_room: Option<OwnedRoomId>,
     room: String,
-    rooms: BTreeMap<Box<RoomId>, Box<RoomName>>,
-    current_room: Option<Box<RoomId>>,
-    room_id_to_canonical_alias: BTreeMap<Box<RoomId>, Box<RoomAliasId>>,
+    rooms: BTreeMap<OwnedRoomId, OwnedRoomName>,
+    current_room: Option<OwnedRoomId>,
+    room_id_to_canonical_alias: BTreeMap<OwnedRoomId, OwnedRoomAliasId>,
     auth_token: Option<String>,
-    joined_rooms: Vec<Box<RoomId>>,
-    room_to_direct_name: BTreeMap<Box<RoomId>, String>,
-    room_to_aliases: BTreeMap<Box<RoomId>, Vec<Box<RoomAliasId>>>,
-    alias_to_room: BTreeMap<Box<RoomAliasId>, Box<RoomId>>,
+    joined_rooms: Vec<OwnedRoomId>,
+    room_to_direct_name: BTreeMap<OwnedRoomId, String>,
+    room_to_aliases: BTreeMap<OwnedRoomId, Vec<OwnedRoomAliasId>>,
+    alias_to_room: BTreeMap<OwnedRoomAliasId, OwnedRoomId>,
     room_list_top: usize,
     room_list_height: usize,
     room_list_top_backup: usize,
@@ -229,17 +229,17 @@ async fn main() -> Result<(), Box<dyn Error>> {
 #[derive(Debug, Clone, Eq, PartialEq)]
 enum SyncMessage {
     Quit,
-    SendMessage(Box<RoomId>, String, String, bool),
+    SendMessage(OwnedRoomId, String, String, bool),
     InitialSyncOver,
     RoomsUpdated(
-        Vec<Box<RoomId>>,
-        BTreeMap<Box<RoomId>, Box<RoomName>>,
-        BTreeMap<Box<RoomId>, Box<RoomAliasId>>,
-        BTreeMap<Box<RoomId>, String>,
-        BTreeMap<Box<RoomId>, Vec<Box<RoomAliasId>>>,
-        BTreeMap<Box<RoomAliasId>, Box<RoomId>>,
+        Vec<OwnedRoomId>,
+        BTreeMap<OwnedRoomId, OwnedRoomName>,
+        BTreeMap<OwnedRoomId, OwnedRoomAliasId>,
+        BTreeMap<OwnedRoomId, String>,
+        BTreeMap<OwnedRoomId, Vec<OwnedRoomAliasId>>,
+        BTreeMap<OwnedRoomAliasId, OwnedRoomId>,
     ),
-    LeaveRoom(Box<RoomId>),
+    LeaveRoom(OwnedRoomId),
     JoinRoom(String),
 }
 #[allow(unused_assignments)]
@@ -614,7 +614,7 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &mut App) {
     }
     if app.joined_rooms.len() > 0 {
         if app.room_list_prev_height != app.room_list_height {
-            let chosen: Box<RoomId>;
+            let chosen: OwnedRoomId;
             if app.selected_room.is_none() {
                 chosen = app.current_room.clone().unwrap();
             } else {
